#
# spec file for package steamtricks
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           steamtricks
Version:        0.3.0
Release:        1.1
Summary:        Workarounds for problems with Steam on Linux
License:        GPL-2.0
Group:          Amusements/Games/Other
Url:            https://steamtricks.github.io/steamtricks/
Source:         %{name}-%{version}.tar.xz
BuildArch:      noarch
BuildRequires:  systemd-rpm-macros
Recommends:     steamtricks-data
# see https://github.com/steamtricks/steamtricks/issues/27
Requires:       coreutils
Requires:       findutils
Requires:       grep
Requires:       patch
Requires:       rpm
Requires:       sed
# steamtricksd.service file utilizes `script`
Requires:       util-linux
Requires:       which
%{?systemd_requires}

%description
steamtricks provides workarounds for problems with Steam on Linux.

Steam primarily targets Ubuntu and not the wider base of Linux distributions.
This has led to a number of suboptimal experiences for users not on an
officially supported distribution. The goal of this project is to
provide workarounds and solutions to those problems in an easy to use package.
Currently, workarounds exist in some distribution packages and in various forums
and the like. This project aims to be the upstream source for packaging Steam
fixes.

%prep
%setup -q

%build

%install
%make_install VERSION="%{version}"

%files
%defattr(-,root,root,-)
%doc COPYING AUTHORS
%{_bindir}/%{name}
%{_datadir}/%{name}
# <= leap 42.1 does not provide _userunitdir
%if 0%{!?_userunitdir:1}
  %define _userunitdir /usr/lib/systemd/user
  %dir /usr/lib/systemd/user
%endif
%{_userunitdir}/%{name}d.service

%changelog
* Thu May 18 2017 jimmy@boombatower.com
- Update to version 0.3.0:
  * Suspend event processing while apps are running.
  * Check if new packages are available before prompting the user.
  * Escape single quotes in strip_quotes() to resolve parsing issues.
  * Look for an installable data package for each app.
  * Add strip_name() to clean app_name before trying as package name.
  * Rework command line parsing to pave the way for commands.
  * Add apply command to force apply fixes to an app.
  * Correct dependency cache read so that both variables are loaded.
  * Disable openssl replacement when nvidia binary driver detected.
  * Allow for multi-part .so version numbers and .bin files in dep list regex.
  * Update README to include more information.
* Tue Feb 14 2017 jimmy@boombatower.com
- Update to version 0.2.1:
  * Increment applied when steamtricks_fix_script() script is executed.
* Sun Oct 16 2016 jimmy@boombatower.com
- Update to version 0.2.0:
  * Include systemd daemon-reload in dist steam patch.
  * Import DISPLAY and XDG_CURRENT_DESKTOP into systemctl.
  * Expand fix_deps() find to utilize a regex.
  * fix_deps(): Provide a file list cache in addition to needs cache.
  * fix_deps(): Only sleep on failure to allow reading of error.
  * fix_deps(): Include steamtricks in the message to be clear.
  * fix_deps(): Provide a notification before evaluating binaries.
  * Utilize -F instead of -f in tail to handle log rotation.
  * Guard openssl replacement with steam-runtime directory check.
  * Workaround konsole oddity by providing a fake stdin.
  * Strip comments from steamtricksd.service file during install.
  * Respect source files and apply sed command to installed.
  * Prefix keyvalue_parse() variables with local to prevent leaking.
* Sun Oct  9 2016 jimmy@boombatower.com
- Update to version 0.1.1:
  * Disable FIX_FETCH notifications by default.
  * Refactor buildid based fix directory detection.
  * Do not depend on zypper result for sleep.
  * Guard fix_deps() with check for zypper.
  * Add a comment about why deps cannot be checked before hand.
  * Provide a user-friendly message preceding sudo request.
  * Create $PREFIX/share/steamtricks directory in Makefile.
* Sun Oct  9 2016 jimmy@boombatower.com
- Add proper list of dependencies.
- Handle <= Leap 42.1 systemd user service packaging.
- Remove manual creation of data dir as upstream now handles.
- Remove systemd pre/post/preun/postun since they cannot handle a
  user service.
* Sat Oct  8 2016 jimmy@boombatower.com
- Update to version 0.1.0:
  * Prefix remove with 00- to be consistent.
  * Add COPYING: GPLv2 just as the Linux kernel.
  * Add AUTHORS: only creator for now.
  * Default FIX_APPLY_PRE to false.
  * Rework app state change detection.
  * Ignore app state changes during validation.
  * Break out data directory application into separate function.
  * Correct typo st[r]eamtricks_fix_script().
  * Allow revision specific fixes.
  * Correct unexecutable `rm` cleanup in fix_deps().
  * Prints all local variables instead of declaring.
  * No need to include installation file name in Makefile.
  * Swap out `tee /dev/stderr` for /dev/shm for systemd.
  * Remove self daemonization in favor of systemd user daemon.
  * Fix oversight after reworking stderr output for systemd.
* Thu Oct  6 2016 jimmy@boombatower.com
- Update to version 0~git20161006.ca85dd1:
  * Provide C_DATA_DIR to easily allow overriding data dir.
  * Only attempt to use developement data dir when present.
  * Alter notify() to echo message into log.
  * Add notification when fix_apply() begins.
  * Refactor $appid to $app_id in steam_app_manifest() for consistency.
  * Initial fix dependencies implementation.
  * Always include dependencies in notification.
  * Provide FIX_APPLY_NONE notification.
  * Include steamtricks in already running message.
  * Provide --daemon flag with log rotation.
  * Document --version flag.
  * Update dist patch to use --daemon flag.
* Wed Oct  5 2016 jimmy@boombatower.com
- Update to version 0~git20161004.e77dcfe:
  * Add VERSION to Makefile build.
- Set VERSION to rpm version.
* Wed Oct  5 2016 jimmy@boombatower.com
- Remove steam requirement as steam require steamtricks.
* Wed Oct  5 2016 jimmy@boombatower.com
- Initial package.
